IosSecurityOptions class

Inheritance
Annotations
  • @freezed

Constructors

IosSecurityOptions({required String bundleId, String? mobileProvision, String? jsonFileName, String? cryptographicKey, List<String>? listOfPaths})
IosSecurityOptions class containing options for iOs
factory
IosSecurityOptions.fromJson(Map<String, dynamic> json)
factory

Properties

bundleId → String
no setterinherited
copyWith → $IosSecurityOptionsCopyWith<IosSecurityOptions>
no setterinherited
cryptographicKey → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
jsonFileName → String?
no setterinherited
listOfPaths → List<String>?
no setterinherited
mobileProvision → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited